"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "PseudoHtml", {
    enumerable: true,
    get: function() {
        return PseudoHtml;
    }
});
const _jsxruntime = require("react/jsx-runtime");
const _react = require("react");
const _GroupedStackFrames = require("./GroupedStackFrames");
const MAX_NON_COLLAPSED_FRAMES = 6;
function PseudoHtml(param) {
    let { componentStackFrames, serverTagName, clientTagName, ...props } = param;
    const isHtmlTagsWarning = serverTagName || clientTagName;
    const shouldCollapse = componentStackFrames.length > MAX_NON_COLLAPSED_FRAMES;
    const [isHtmlCollapsed, toggleCollapseHtml] = (0, _react.useState)(shouldCollapse);
    const htmlComponents = (0, _react.useMemo)(()=>{
        const tagNames = [
            serverTagName,
            clientTagName
        ];
        const nestedHtmlStack = [];
        let lastText = "";
        componentStackFrames.map((frame)=>frame.component).reverse().forEach((component, index, componentList)=>{
            const spaces = " ".repeat(nestedHtmlStack.length * 2);
            const prevComponent = componentList[index - 1];
            const nextComponent = componentList[index + 1];
            // When component is the server or client tag name, highlight it
            const isHighlightedTag = tagNames.includes(component);
            const isRelatedTag = isHighlightedTag || tagNames.includes(prevComponent) || tagNames.includes(nextComponent);
            if (nestedHtmlStack.length >= MAX_NON_COLLAPSED_FRAMES && isHtmlCollapsed) {
                return;
            }
            if (isRelatedTag) {
                const TextWrap = isHighlightedTag ? "b" : _react.Fragment;
                const codeLine = /*#__PURE__*/ (0, _jsxruntime.jsxs)("span", {
                    children: [
                        /*#__PURE__*/ (0, _jsxruntime.jsx)("span", {
                            children: spaces
                        }),
                        /*#__PURE__*/ (0, _jsxruntime.jsxs)(TextWrap, {
                            children: [
                                "<",
                                component,
                                ">",
                                "\n"
                            ]
                        })
                    ]
                });
                lastText = component;
                const wrappedCodeLine = /*#__PURE__*/ (0, _jsxruntime.jsxs)(_react.Fragment, {
                    children: [
                        codeLine,
                        isHighlightedTag && /*#__PURE__*/ (0, _jsxruntime.jsx)("span", {
                            children: spaces + "^".repeat(component.length + 2) + "\n"
                        })
                    ]
                }, nestedHtmlStack.length);
                nestedHtmlStack.push(wrappedCodeLine);
            } else {
                if (!isHtmlCollapsed || !isHtmlTagsWarning) {
                    nestedHtmlStack.push(/*#__PURE__*/ (0, _jsxruntime.jsxs)("span", {
                        children: [
                            spaces,
                            "<" + component + ">\n"
                        ]
                    }, nestedHtmlStack.length));
                } else if (lastText !== "...") {
                    lastText = "...";
                    nestedHtmlStack.push(/*#__PURE__*/ (0, _jsxruntime.jsxs)("span", {
                        children: [
                            spaces,
                            "...",
                            "\n"
                        ]
                    }, nestedHtmlStack.length));
                }
            }
        });
        return nestedHtmlStack;
    }, [
        componentStackFrames,
        isHtmlCollapsed,
        clientTagName,
        serverTagName,
        isHtmlTagsWarning
    ]);
    return /*#__PURE__*/ (0, _jsxruntime.jsxs)("div", {
        "data-nextjs-container-errors-pseudo-html": true,
        children: [
            /*#__PURE__*/ (0, _jsxruntime.jsx)("span", {
                "data-nextjs-container-errors-pseudo-html-collapse": true,
                onClick: ()=>toggleCollapseHtml(!isHtmlCollapsed),
                children: /*#__PURE__*/ (0, _jsxruntime.jsx)(_GroupedStackFrames.CollapseIcon, {
                    collapsed: isHtmlCollapsed
                })
            }),
            /*#__PURE__*/ (0, _jsxruntime.jsx)("pre", {
                ...props,
                children: /*#__PURE__*/ (0, _jsxruntime.jsx)("code", {
                    children: htmlComponents
                })
            })
        ]
    });
}

if ((typeof exports.default === 'function' || (typeof exports.default === 'object' && exports.default !== null)) && typeof exports.default.__esModule === 'undefined') {
  Object.defineProperty(exports.default, '__esModule', { value: true });
  Object.assign(exports.default, exports);
  module.exports = exports.default;
}

//# sourceMappingURL=component-stack-pseudo-html.js.map