import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, Fragment, useState } from "react";
import { CollapseIcon } from "./GroupedStackFrames";
const MAX_NON_COLLAPSED_FRAMES = 6;
/**
 *
 * Format component stack into pseudo HTML
 * component stack is an array of strings, e.g.: ['p', 'p', 'Page', ...]
 *
 * Will render it for the code block
 *
 * <pre>
 *  <code>{`
 *    <Page>
 *       <p>
 *       ^^^^
 *         <p>
 *         ^^^^
 *  `}</code>
 * </pre>
 *
 */ export function PseudoHtml(param) {
    let { componentStackFrames, serverTagName, clientTagName, ...props } = param;
    const isHtmlTagsWarning = serverTagName || clientTagName;
    const shouldCollapse = componentStackFrames.length > MAX_NON_COLLAPSED_FRAMES;
    const [isHtmlCollapsed, toggleCollapseHtml] = useState(shouldCollapse);
    const htmlComponents = useMemo(()=>{
        const tagNames = [
            serverTagName,
            clientTagName
        ];
        const nestedHtmlStack = [];
        let lastText = "";
        componentStackFrames.map((frame)=>frame.component).reverse().forEach((component, index, componentList)=>{
            const spaces = " ".repeat(nestedHtmlStack.length * 2);
            const prevComponent = componentList[index - 1];
            const nextComponent = componentList[index + 1];
            // When component is the server or client tag name, highlight it
            const isHighlightedTag = tagNames.includes(component);
            const isRelatedTag = isHighlightedTag || tagNames.includes(prevComponent) || tagNames.includes(nextComponent);
            if (nestedHtmlStack.length >= MAX_NON_COLLAPSED_FRAMES && isHtmlCollapsed) {
                return;
            }
            if (isRelatedTag) {
                const TextWrap = isHighlightedTag ? "b" : Fragment;
                const codeLine = /*#__PURE__*/ _jsxs("span", {
                    children: [
                        /*#__PURE__*/ _jsx("span", {
                            children: spaces
                        }),
                        /*#__PURE__*/ _jsxs(TextWrap, {
                            children: [
                                "<",
                                component,
                                ">",
                                "\n"
                            ]
                        })
                    ]
                });
                lastText = component;
                const wrappedCodeLine = /*#__PURE__*/ _jsxs(Fragment, {
                    children: [
                        codeLine,
                        isHighlightedTag && /*#__PURE__*/ _jsx("span", {
                            children: spaces + "^".repeat(component.length + 2) + "\n"
                        })
                    ]
                }, nestedHtmlStack.length);
                nestedHtmlStack.push(wrappedCodeLine);
            } else {
                if (!isHtmlCollapsed || !isHtmlTagsWarning) {
                    nestedHtmlStack.push(/*#__PURE__*/ _jsxs("span", {
                        children: [
                            spaces,
                            "<" + component + ">\n"
                        ]
                    }, nestedHtmlStack.length));
                } else if (lastText !== "...") {
                    lastText = "...";
                    nestedHtmlStack.push(/*#__PURE__*/ _jsxs("span", {
                        children: [
                            spaces,
                            "...",
                            "\n"
                        ]
                    }, nestedHtmlStack.length));
                }
            }
        });
        return nestedHtmlStack;
    }, [
        componentStackFrames,
        isHtmlCollapsed,
        clientTagName,
        serverTagName,
        isHtmlTagsWarning
    ]);
    return /*#__PURE__*/ _jsxs("div", {
        "data-nextjs-container-errors-pseudo-html": true,
        children: [
            /*#__PURE__*/ _jsx("span", {
                "data-nextjs-container-errors-pseudo-html-collapse": true,
                onClick: ()=>toggleCollapseHtml(!isHtmlCollapsed),
                children: /*#__PURE__*/ _jsx(CollapseIcon, {
                    collapsed: isHtmlCollapsed
                })
            }),
            /*#__PURE__*/ _jsx("pre", {
                ...props,
                children: /*#__PURE__*/ _jsx("code", {
                    children: htmlComponents
                })
            })
        ]
    });
}

//# sourceMappingURL=component-stack-pseudo-html.js.map